summaryrefslogtreecommitdiff
path: root/src/arch/dalvik/context.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/dalvik/context.h')
-rw-r--r--src/arch/dalvik/context.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/arch/dalvik/context.h b/src/arch/dalvik/context.h
index 711849d..09fc256 100644
--- a/src/arch/dalvik/context.h
+++ b/src/arch/dalvik/context.h
@@ -29,6 +29,7 @@
#include <stdbool.h>
+#include "instruction.h"
#include "../archbase.h"
#include "../../decomp/context.h"
@@ -58,16 +59,14 @@ GType g_dalvik_context_get_type(void);
/* Crée un contexte pour l'exécution du processeur Dalvik. */
GDalvikContext *g_dalvik_context_new(void);
+/* Mémorise une zone comme étant des données de branchements. */
+bool g_dalvik_context_register_switch_data(GDalvikContext *ctx, const vmpa2t *start, phys_t length);
+/* Mémorise une zone comme étant des données d'un tableau. */
+bool g_dalvik_context_register_array_data(GDalvikContext *, const vmpa2t *, uint16_t, phys_t);
-/* ------------------------- MEMORISATION DES SAUTS DE CODE ------------------------- */
-
-
-/* Mémorise une nouvelle zone de code comme étant des données. */
-void g_dalvik_context_skip_new_area(GDalvikContext *, vmpa_t, vmpa_t);
-
-/* Indique si l'adresse est considérée comme zone de données. */
-bool g_dalvik_context_have_to_skip(GDalvikContext *, vmpa_t);
+/* Place une donnée en tant qu'instruction si besoin est. */
+GArchInstruction *g_dalvik_context_get_raw_data(GDalvikContext *, const GBinContent *, vmpa2t *);